@@ -11,7 +11,6 @@ def complexity_hjorth(signal):
     NeuroKit returns complexity directly in the output tuple, but the other parameters can be found
     in the dictionary.
 
-
     * The **activity** parameter is simply the variance of the signal, which corresponds to the
       mean power of a signal (if its mean is 0).
 
@@ -19,6 +18,14 @@ def complexity_hjorth(signal):
 
         Activity = \\sigma_{signal}^2
 
+    * The **mobility** parameter represents the mean frequency or the proportion of standard
+      deviation of the power spectrum. This is defined as the square root of variance of the
+      first derivative of the signal divided by the variance of the signal.
+
+      .. math::
+
+        Mobility = \\frac{\\sigma_{dd}/ \\sigma_{d}}{Complexity}
+
     * The **complexity** parameter gives an estimate of the bandwidth of the signal, which
       indicates the similarity of the shape of the signal to a pure sine wave (for which the
       value converges to 1). In other words, it is a measure of the "excessive details" with
@@ -29,14 +36,6 @@ def complexity_hjorth(signal):
 
         Complexity = \\sigma_{d}/ \\sigma_{signal}
 
-    * The **mobility** parameter represents the mean frequency or the proportion of standard
-      deviation of the power spectrum. This is defined as the square root of variance of the
-      first derivative of the signal divided by the variance of the signal.
-
-      .. math::
-
-        Mobility = \\frac{\\sigma_{dd}/ \\sigma_{d}}{Complexity}
-
     :math:`d` and :math:`dd` represent the first and second derivatives of the signal, respectively.
 
     Hjorth (1970) illustrated the parameters as follows:
@@ -59,7 +58,7 @@ def complexity_hjorth(signal):
     Returns
     -------
     hjorth : float
-         Hjorth's Complexity.
+        Hjorth's Complexity.
     info : dict
         A dictionary containing the additional Hjorth parameters, such as ``"Mobility"`` and
         ``"Activity"``.
@@ -81,7 +80,7 @@ def complexity_hjorth(signal):
     References
     ----------
     * Hjorth, B (1970) EEG Analysis Based on Time Domain Properties. Electroencephalography and
-      Clinical Neurophysiology, 29, 306-310. http://dx.doi.org/10.1016/0013-4694(70)90143-4
+      Clinical Neurophysiology, 29, 306-310.
 
     """
     # Sanity checks
