@@ -6,21 +6,6 @@ def write_csv(data, filename, parts=None, **kwargs):
 
     Split the data into multiple CSV files. You can then re-create them as follows:
 
-    Example
-    --------
-    .. ipython:: python
-
-      import pandas as pd
-      import neurokit2 as nk
-
-      # Split data into multiple files
-      # nk.write_csv(data, 'C:/Users/.../data.csv', parts=6)
-
-      # Iterate through 6-parts and concatenate the pieces
-      # data_all = pd.concat(
-      #                   [pd.read_csv(f"data_part{i}.csv") for i in range(1, 7)],
-      #                   axis=0,
-      #                      )
 
     Parameters
     ----------
@@ -33,7 +18,29 @@ def write_csv(data, filename, parts=None, **kwargs):
 
     Returns
     -------
-    None.
+    None
+
+    Example
+    --------
+    Save big file in parts
+
+    .. ipython:: python
+
+      import pandas as pd
+      import neurokit2 as nk
+
+      # Split data into multiple files
+      # nk.write_csv(data, 'C:/Users/.../data', parts=6)
+
+    Read the files back
+
+    .. ipython:: python
+
+      # Iterate through 6-parts and concatenate the pieces
+      # data_all = pd.concat(
+      #     [pd.read_csv(f"data_part{i}.csv") for i in range(1, 7)],
+      #     axis=0,
+      # )
 
     """
     if isinstance(parts, int):
