@@ -10,7 +10,7 @@ from ..signal import signal_filter, signal_smooth
 
 
 def eda_clean(eda_signal, sampling_rate=1000, method="neurokit"):
-    """Preprocess Electrodermal Activity (EDA) signal.
+    """**Preprocess Electrodermal Activity (EDA) signal**
 
     Parameters
     ----------
@@ -19,7 +19,7 @@ def eda_clean(eda_signal, sampling_rate=1000, method="neurokit"):
     sampling_rate : int
         The sampling frequency of `rsp_signal` (in Hz, i.e., samples/second).
     method : str
-        The processing pipeline to apply. Can be one of 'neurokit' (default) or 'biosppy'.
+        The processing pipeline to apply. Can be one of ``"neurokit"`` (default) or ``"biosppy"``.
 
     Returns
     -------
@@ -32,15 +32,20 @@ def eda_clean(eda_signal, sampling_rate=1000, method="neurokit"):
 
     Examples
     --------
-    >>> import pandas as pd
-    >>> import neurokit2 as nk
-    >>>
-    >>> eda = nk.eda_simulate(duration=30, sampling_rate=100, scr_number=10, noise=0.01, drift=0.02)
-    >>> signals = pd.DataFrame({"EDA_Raw": eda,
-    ...                         "EDA_BioSPPy": nk.eda_clean(eda, sampling_rate=100,method='biosppy'),
-    ...                         "EDA_NeuroKit": nk.eda_clean(eda, sampling_rate=100, method='neurokit')})
-    >>> fig = signals.plot()
-    >>> fig #doctest: +SKIP
+    .. ipython:: python
+
+      import pandas as pd
+      import neurokit2 as nk
+
+      eda = nk.eda_simulate(duration=30, sampling_rate=100, scr_number=10, noise=0.01, drift=0.02)
+      signals = pd.DataFrame({"EDA_Raw": eda,
+                              "EDA_BioSPPy": nk.eda_clean(eda, sampling_rate=100,method='biosppy'),
+                              "EDA_NeuroKit": nk.eda_clean(eda, sampling_rate=100,
+                              method='neurokit')})
+      @savefig p_eda_clean.png scale=100%
+      fig = signals.plot()
+      @suppress
+      plt.close()
 
     """
     eda_signal = as_vector(eda_signal)
