@@ -2,10 +2,11 @@ import os
 
 
 def mne_templateMRI(verbose="WARNING"):
-    """
-    This function is a helper that returns the path of the MRI template for adults (the ``src`` and the
-    ``bem``) that is made available through ``MNE``. It downloads the data if need be. These templates
-    can be used for EEG source reconstruction when no individual MRI is available.
+    """**Return Path of MRI Template**
+
+    This function is a helper that returns the path of the MRI template for adults (the ``src`` and
+    the ``bem``) that is made available through ``"MNE"``. It downloads the data if need be. These
+    templates can be used for EEG source reconstruction when no individual MRI is available.
 
     See https://mne.tools/stable/auto_tutorials/forward/35_eeg_no_mri.html
 
@@ -16,9 +17,12 @@ def mne_templateMRI(verbose="WARNING"):
 
     Examples
     ---------
-    >>> import neurokit2 as nk
-    >>>
-    >>> src, bem = nk.mne_templateMRI() # doctest: +SKIP
+    .. ipython:: python
+
+      import neurokit2 as nk
+
+      src, bem = nk.mne_templateMRI()
+
     """
     # Try loading mne (requires also the 'pooch' package)
     try:
