@@ -5,23 +5,24 @@ import numpy as np
 import pandas as pd
 import scipy.signal
 
-from ..misc import as_vector, NeuroKitWarning
+from ..misc import NeuroKitWarning, as_vector
 from ..signal import signal_detrend
 
 
 def emg_clean(emg_signal, sampling_rate=1000):
-    """Preprocess an electromyography (emg) signal.
+    """**Preprocess an electromyography (emg) signal**
 
-    Clean an EMG signal using a set of parameters, such as: in `BioSPPy
-    <https://github.com/PIA-Group/BioSPPy/blob/e65da30f6379852ecb98f8e2e0c9b4b5175416c3/biosppy/signals/emg.py>>`_:
-    fourth order 100 Hz highpass Butterworth filter followed by a constant detrending.
+    Clean an EMG signal using a set of parameters. Only one method is available at the moment.
+
+    * **BioSPPy**: fourth order 100 Hz highpass Butterworth filter followed by a constant
+      detrending.
 
     Parameters
     ----------
     emg_signal : Union[list, np.array, pd.Series]
         The raw EMG channel.
     sampling_rate : int
-        The sampling frequency of `emg_signal` (in Hz, i.e., samples/second).
+        The sampling frequency of ``emg_signal`` (in Hz, i.e., samples/second).
         Defaults to 1000.
 
     Returns
@@ -35,13 +36,17 @@ def emg_clean(emg_signal, sampling_rate=1000):
 
     Examples
     --------
-    >>> import pandas as pd
-    >>> import neurokit2 as nk
-    >>>
-    >>> emg = nk.emg_simulate(duration=10, sampling_rate=1000)
-    >>> signals = pd.DataFrame({"EMG_Raw": emg, "EMG_Cleaned":nk.emg_clean(emg, sampling_rate=1000)})
-    >>> fig = signals.plot()
-    >>> fig #doctest: +SKIP
+    .. ipython:: python
+
+      import pandas as pd
+      import neurokit2 as nk
+
+      emg = nk.emg_simulate(duration=10, sampling_rate=1000)
+      signals = pd.DataFrame({"EMG_Raw": emg, "EMG_Cleaned":nk.emg_clean(emg, sampling_rate=1000)})
+      @savefig p_emg_clean1.png scale=100%
+      fig = signals.plot()
+      @suppress
+      plt.close()
 
     """
     emg_signal = as_vector(emg_signal)
@@ -52,14 +57,16 @@ def emg_clean(emg_signal, sampling_rate=1000):
         warn(
             "There are " + str(n_missing) + " missing data points in your signal."
             " Filling missing values by using the forward filling method.",
-            category=NeuroKitWarning
+            category=NeuroKitWarning,
         )
         emg_signal = _emg_clean_missing(emg_signal)
 
     # Parameters
     order = 4
     frequency = 100
-    frequency = 2 * np.array(frequency) / sampling_rate  # Normalize frequency to Nyquist Frequency (Fs/2).
+    frequency = (
+        2 * np.array(frequency) / sampling_rate
+    )  # Normalize frequency to Nyquist Frequency (Fs/2).
 
     # Filtering
     b, a = scipy.signal.butter(N=order, Wn=frequency, btype="highpass", analog=False)
@@ -70,6 +77,7 @@ def emg_clean(emg_signal, sampling_rate=1000):
 
     return clean
 
+
 # =============================================================================
 # Handle missing data
 # =============================================================================
