@@ -5,9 +5,15 @@ from ..signal import signal_resample
 
 
 def emg_simulate(
-    duration=10, length=None, sampling_rate=1000, noise=0.01, burst_number=1, burst_duration=1.0, random_state=42
+    duration=10,
+    length=None,
+    sampling_rate=1000,
+    noise=0.01,
+    burst_number=1,
+    burst_duration=1.0,
+    random_state=42,
 ):
-    """Simulate an EMG signal.
+    """**Simulate an EMG signal**
 
     Generate an artificial (synthetic) EMG signal of a given duration and sampling rate.
 
@@ -36,12 +42,16 @@ def emg_simulate(
 
     Examples
     ----------
-    >>> import neurokit2 as nk
-    >>> import pandas as pd
-    >>>
-    >>> emg = nk.emg_simulate(duration=10, burst_number=3)
-    >>> fig = nk.signal_plot(emg)
-    >>> fig #doctest: +SKIP
+    .. ipython:: python
+
+      import neurokit2 as nk
+      import pandas as pd
+
+      emg = nk.emg_simulate(duration=10, burst_number=3)
+      @savefig p_emg_simulate1.png scale=100%
+      fig = nk.signal_plot(emg)
+      @suppress
+      plt.close()
 
     See Also
     --------
@@ -100,6 +110,8 @@ def emg_simulate(
     emg += np.random.normal(0, noise, len(emg))
 
     # Resample
-    emg = signal_resample(emg, sampling_rate=1000, desired_length=length, desired_sampling_rate=sampling_rate)
+    emg = signal_resample(
+        emg, sampling_rate=1000, desired_length=length, desired_sampling_rate=sampling_rate
+    )
 
     return emg
