@@ -10,9 +10,9 @@ from .find_groups import find_groups
 from .find_knee import find_knee
 from .find_outliers import find_outliers
 from .find_plateau import find_plateau
-from .intervals_to_peaks import intervals_to_peaks
 from .listify import listify
 from .parallel_run import parallel_run
+from .progress_bar import progress_bar
 from .replace import replace
 from .type_converters import as_vector
 
@@ -28,8 +28,8 @@ __all__ = [
     "NeuroKitWarning",
     "check_type",
     "find_outliers",
-    "intervals_to_peaks",
     "parallel_run",
+    "progress_bar",
     "find_plateau",
     "copyfunction",
 ]
