@@ -1,16 +1,24 @@
 # -*- coding: utf-8 -*-
 import pandas as pd
 
-from ..signal import signal_rate, signal_sanitize
+from ..misc import as_vector
+from ..signal import signal_rate
 from .rsp_amplitude import rsp_amplitude
 from .rsp_clean import rsp_clean
+from .rsp_methods import rsp_methods
 from .rsp_peaks import rsp_peaks
 from .rsp_phase import rsp_phase
 from .rsp_rvt import rsp_rvt
 from .rsp_symmetry import rsp_symmetry
 
 
-def rsp_process(rsp_signal, sampling_rate=1000, method="khodadad2018"):
+def rsp_process(
+    rsp_signal,
+    sampling_rate=1000,
+    method="khodadad2018",
+    method_rvt="harrison2021",
+    **kwargs
+):
     """**Process a respiration (RSP) signal**
 
     Convenience function that automatically processes a respiration signal with one of the
@@ -29,6 +37,12 @@ def rsp_process(rsp_signal, sampling_rate=1000, method="khodadad2018"):
     method : str
         The processing pipeline to apply. Can be one of ``"khodadad2018"`` (default)
         or ``"biosppy"``.
+    method_rvt : str
+        The rvt method to apply. Can be one of ``"harrison2021"`` (default), ``"birn2006"``
+        or ``"power2020"``.
+    **kwargs
+        Other arguments to be passed to specific methods. For more information,
+        see :func:`.rsp_methods`.
 
     Returns
     -------
@@ -72,14 +86,33 @@ def rsp_process(rsp_signal, sampling_rate=1000, method="khodadad2018"):
 
     """
     # Sanitize input
-    rsp_signal = signal_sanitize(rsp_signal)
+    rsp_signal = as_vector(rsp_signal)
+    methods = rsp_methods(
+        sampling_rate=sampling_rate, method=method, method_rvt=method_rvt, **kwargs
+    )
 
     # Clean signal
-    rsp_cleaned = rsp_clean(rsp_signal, sampling_rate=sampling_rate, method=method)
+    if (
+        methods["method_cleaning"] is None
+        or methods["method_cleaning"].lower() == "none"
+    ):
+        rsp_cleaned = rsp_signal
+    else:
+        # Clean signal
+        rsp_cleaned = rsp_clean(
+            rsp_signal,
+            sampling_rate=sampling_rate,
+            method=methods["method_cleaning"],
+            **methods["kwargs_cleaning"],
+        )
 
     # Extract, fix and format peaks
     peak_signal, info = rsp_peaks(
-        rsp_cleaned, sampling_rate=sampling_rate, method=method, amplitude_min=0.3
+        rsp_cleaned,
+        sampling_rate=sampling_rate,
+        method=methods["method_peaks"],
+        amplitude_min=0.3,
+        **methods["kwargs_peaks"],
     )
     info["sampling_rate"] = sampling_rate  # Add sampling rate in dict info
 
@@ -90,7 +123,12 @@ def rsp_process(rsp_signal, sampling_rate=1000, method="khodadad2018"):
         info["RSP_Troughs"], sampling_rate=sampling_rate, desired_length=len(rsp_signal)
     )
     symmetry = rsp_symmetry(rsp_cleaned, peak_signal)
-    rvt = rsp_rvt(rsp_cleaned, sampling_rate=sampling_rate, silent=True)
+    rvt = rsp_rvt(
+        rsp_cleaned,
+        method=methods["method_rvt"],
+        sampling_rate=sampling_rate,
+        silent=True,
+    )
 
     # Prepare output
     signals = pd.DataFrame(
