@@ -1,9 +1,12 @@
 # - * - coding: utf-8 - * -
+from warnings import warn
+
 import matplotlib.patches
 import matplotlib.pyplot as plt
 import numpy as np
 import pandas as pd
 
+from ..misc import NeuroKitWarning
 from ..stats import standardize
 from .signal_formatpeaks import _signal_formatpeaks_sanitize
 from .signal_period import signal_period
@@ -53,7 +56,7 @@ def signal_fixpeaks(
         the sample (expressed in standard deviation from the mean).
     robust : bool
         Only when ``method = "neurokit"``. Use a robust method of standardization (see
-        `standardize`) for the relative thresholds.
+        :func:`.standardize`) for the relative thresholds.
     method : str
         Either ``"Kubios"`` or ``"neurokit"``. ``"Kubios"`` uses the artifact detection and
         correction described in Lipponen, J. A., & Tarvainen, M. P. (2019). Note that ``"Kubios"``
@@ -145,9 +148,7 @@ def signal_fixpeaks(
 
     # If method Kubios
     if method.lower() == "kubios":
-        return _signal_fixpeaks_kubios(
-            peaks, sampling_rate=sampling_rate, iterative=iterative, show=show, **kwargs
-        )
+        return _signal_fixpeaks_kubios(peaks, sampling_rate=sampling_rate, iterative=iterative, show=show, **kwargs)
     else:
         # Else method is NeuroKit
         return _signal_fixpeaks_neurokit(
@@ -176,10 +177,16 @@ def _signal_fixpeaks_neurokit(
     """NeuroKit method."""
 
     peaks_clean = _remove_small(peaks, sampling_rate, interval_min, relative_interval_min, robust)
-    peaks_clean = _interpolate_big(
-        peaks_clean, sampling_rate, interval_max, relative_interval_max, robust
-    )
+    peaks_clean = _interpolate_big(peaks_clean, sampling_rate, interval_max, relative_interval_max, robust,)
 
+    valid_peaks = peaks_clean[peaks_clean >= 0]
+    n_invalid_idcs = len(peaks_clean) - len(valid_peaks)
+    if n_invalid_idcs > 0:
+        warn(
+            f" Negative peak indices detected in output. " f" Removing {n_invalid_idcs} invalid peaks. ",
+            category=NeuroKitWarning,
+        )
+        peaks_clean = valid_peaks
     return peaks_clean
 
 
@@ -198,22 +205,17 @@ def _signal_fixpeaks_kubios(peaks, sampling_rate=1000, iterative=True, show=Fals
 
         while True:
 
-            new_artifacts, new_subspaces = _find_artifacts(
-                peaks_clean, sampling_rate=sampling_rate, **kwargs
-            )
+            new_artifacts, new_subspaces = _find_artifacts(peaks_clean, sampling_rate=sampling_rate, **kwargs)
 
             n_artifacts_previous = n_artifacts_current
             n_artifacts_current = sum([len(i) for i in new_artifacts.values()])
             if n_artifacts_current >= n_artifacts_previous:
                 break
-
             artifacts = new_artifacts
             subspaces = new_subspaces
             peaks_clean = _correct_artifacts(artifacts, peaks_clean)
-
     if show:
         _plot_artifacts_lipponen2019(artifacts, subspaces)
-
     return artifacts, peaks_clean
 
 
@@ -221,7 +223,7 @@ def _signal_fixpeaks_kubios(peaks, sampling_rate=1000, iterative=True, show=Fals
 # Kubios: Lipponen & Tarvainen (2019).
 # =============================================================================
 def _find_artifacts(
-    peaks, c1=0.13, c2=0.17, alpha=5.2, window_width=91, medfilt_order=11, sampling_rate=1000
+    peaks, c1=0.13, c2=0.17, alpha=5.2, window_width=91, medfilt_order=11, sampling_rate=1000,
 ):
 
     # Compute period series (make sure it has same numer of elements as peaks);
@@ -257,7 +259,6 @@ def _find_artifacts(
             s12[d - padding] = np.max([drrs_pad[d - 1], drrs_pad[d + 1]])
         elif drrs_pad[d] < 0:
             s12[d - padding] = np.min([drrs_pad[d - 1], drrs_pad[d + 1]])
-
     # Cast dRRs to subspace s22.
     s22 = np.zeros(drrs.size)
     for d in np.arange(padding, padding + drrs.size):
@@ -266,7 +267,6 @@ def _find_artifacts(
             s22[d - padding] = np.min([drrs_pad[d + 1], drrs_pad[d + 2]])
         elif drrs_pad[d] < 0:
             s22[d - padding] = np.max([drrs_pad[d + 1], drrs_pad[d + 2]])
-
     # Compute mRRs: time series of deviation of RRs from median.
     df = pd.DataFrame({"signal": rr})
     medrr = df.rolling(medfilt_order, center=True, min_periods=1).median().signal.values
@@ -307,7 +307,6 @@ def _find_artifacts(
         # Check if the following beat also needs to be evaluated.
         if np.abs(drrs[i + 1]) < np.abs(drrs[i + 2]):
             longshort_candidates.append(i + 1)
-
         for j in longshort_candidates:
             # Long beat.
             eq3 = np.logical_and(drrs[j] > 1, s22[j] < -1)  # pylint: disable=E1111
@@ -342,7 +341,6 @@ def _find_artifacts(
             # short".
             longshort_idcs.append(j)
             i += 1
-
     # Prepare output
     artifacts = {
         "ectopic": ectopic_idcs,
@@ -351,7 +349,15 @@ def _find_artifacts(
         "longshort": longshort_idcs,
     }
 
-    subspaces = {"rr": rr, "drrs": drrs, "mrrs": mrrs, "s12": s12, "s22": s22, "c1": c1, "c2": c2}
+    subspaces = {
+        "rr": rr,
+        "drrs": drrs,
+        "mrrs": mrrs,
+        "s12": s12,
+        "s22": s22,
+        "c1": c1,
+        "c2": c2,
+    }
 
     return artifacts, subspaces
 
@@ -386,20 +392,16 @@ def _correct_artifacts(artifacts, peaks):
         missed_idcs = _update_indices(extra_idcs, missed_idcs, -1)
         ectopic_idcs = _update_indices(extra_idcs, ectopic_idcs, -1)
         longshort_idcs = _update_indices(extra_idcs, longshort_idcs, -1)
-
     # Add missing peaks.
     if missed_idcs:
         peaks = _correct_missed(missed_idcs, peaks)
         # Update remaining indices.
         ectopic_idcs = _update_indices(missed_idcs, ectopic_idcs, 1)
         longshort_idcs = _update_indices(missed_idcs, longshort_idcs, 1)
-
     if ectopic_idcs:
         peaks = _correct_misaligned(ectopic_idcs, peaks)
-
     if longshort_idcs:
         peaks = _correct_misaligned(longshort_idcs, peaks)
-
     return peaks
 
 
@@ -418,9 +420,7 @@ def _correct_missed(missed_idcs, peaks):
     # Calculate the position(s) of new beat(s). Make sure to not generate
     # negative indices. prev_peaks and next_peaks must have the same
     # number of elements.
-    valid_idcs = np.logical_and(
-        missed_idcs > 1, missed_idcs < len(corrected_peaks)
-    )  # pylint: disable=E1111
+    valid_idcs = np.logical_and(missed_idcs > 1, missed_idcs < len(corrected_peaks))  # pylint: disable=E1111
     missed_idcs = missed_idcs[valid_idcs]
     prev_peaks = corrected_peaks[[i - 1 for i in missed_idcs]]
     next_peaks = corrected_peaks[missed_idcs]
@@ -439,7 +439,7 @@ def _correct_misaligned(misaligned_idcs, peaks):
     # the total number of peaks. prev_peaks and next_peaks must have the
     # same number of elements.
     valid_idcs = np.logical_and(
-        misaligned_idcs > 1, misaligned_idcs < len(corrected_peaks) - 1  # pylint: disable=E1111
+        misaligned_idcs > 1, misaligned_idcs < len(corrected_peaks) - 1,  # pylint: disable=E1111
     )
     misaligned_idcs = misaligned_idcs[valid_idcs]
     prev_peaks = corrected_peaks[[i - 1 for i in misaligned_idcs]]
@@ -460,10 +460,8 @@ def _update_indices(source_idcs, update_idcs, update):
     than s."""
     if not update_idcs:
         return update_idcs
-
     for s in source_idcs:
         update_idcs = [u + update if u > s else u for u in update_idcs]
-
     return list(np.unique(update_idcs))
 
 
@@ -497,14 +495,16 @@ def _plot_artifacts_lipponen2019(artifacts, info):
     ax0.set_title("Artifact types", fontweight="bold")
     ax0.plot(rr, label="heart period")
     ax0.scatter(
-        longshort_idcs, rr[longshort_idcs], marker="x", c="m", s=100, zorder=3, label="long/short"
-    )
-    ax0.scatter(ectopic_idcs, rr[ectopic_idcs], marker="x", c="g", s=100, zorder=3, label="ectopic")
-    ax0.scatter(
-        extra_idcs, rr[extra_idcs], marker="x", c="y", s=100, zorder=3, label="false positive"
+        longshort_idcs, rr[longshort_idcs], marker="x", c="m", s=100, zorder=3, label="long/short",
     )
     ax0.scatter(
-        missed_idcs, rr[missed_idcs], marker="x", c="r", s=100, zorder=3, label="false negative"
+        ectopic_idcs, rr[ectopic_idcs], marker="x", c="g", s=100, zorder=3, label="ectopic",
+    )
+    ax0.scatter(
+        extra_idcs, rr[extra_idcs], marker="x", c="y", s=100, zorder=3, label="false positive",
+    )
+    ax0.scatter(
+        missed_idcs, rr[missed_idcs], marker="x", c="r", s=100, zorder=3, label="false negative",
     )
     ax0.legend(loc="upper right")
 
@@ -531,9 +531,7 @@ def _plot_artifacts_lipponen2019(artifacts, info):
     ax4.set_xlim(-10, 10)
     verts0 = [(-10, 5), (-10, -c1 * -10 + c2), (-1, -c1 * -1 + c2), (-1, 5)]
 
-    poly0 = matplotlib.patches.Polygon(
-        verts0, alpha=0.3, facecolor="r", edgecolor=None, label="ectopic periods"
-    )
+    poly0 = matplotlib.patches.Polygon(verts0, alpha=0.3, facecolor="r", edgecolor=None, label="ectopic periods")
     ax4.add_patch(poly0)
     verts1 = [(1, -c1 * 1 - c2), (1, -5), (10, -5), (10, -c1 * 10 - c2)]
     poly1 = matplotlib.patches.Polygon(verts1, alpha=0.3, facecolor="r", edgecolor=None)
@@ -547,14 +545,10 @@ def _plot_artifacts_lipponen2019(artifacts, info):
     ax3.set_xlim(-10, 10)
     ax3.set_ylim(-10, 10)
     verts2 = [(-10, 10), (-10, 1), (-1, 1), (-1, 10)]
-    poly2 = matplotlib.patches.Polygon(
-        verts2, alpha=0.3, facecolor="r", edgecolor=None, label="short periods"
-    )
+    poly2 = matplotlib.patches.Polygon(verts2, alpha=0.3, facecolor="r", edgecolor=None, label="short periods")
     ax3.add_patch(poly2)
     verts3 = [(1, -1), (1, -10), (10, -10), (10, -1)]
-    poly3 = matplotlib.patches.Polygon(
-        verts3, alpha=0.3, facecolor="y", edgecolor=None, label="long periods"
-    )
+    poly3 = matplotlib.patches.Polygon(verts3, alpha=0.3, facecolor="y", edgecolor=None, label="long periods")
     ax3.add_patch(poly3)
     ax3.legend(loc="upper right")
 
@@ -563,67 +557,55 @@ def _plot_artifacts_lipponen2019(artifacts, info):
 # NeuroKit
 # =============================================================================
 def _remove_small(
-    peaks, sampling_rate=1000, interval_min=None, relative_interval_min=None, robust=False
+    peaks, sampling_rate=1000, interval_min=None, relative_interval_min=None, robust=False,
 ):
     if interval_min is None and relative_interval_min is None:
         return peaks
-
     if interval_min is not None:
         interval = signal_period(peaks, sampling_rate=sampling_rate, desired_length=None)
         peaks = peaks[interval > interval_min]
-
     if relative_interval_min is not None:
         interval = signal_period(peaks, sampling_rate=sampling_rate, desired_length=None)
         peaks = peaks[standardize(interval, robust=robust) > relative_interval_min]
-
     return peaks
 
 
 def _interpolate_big(
-    peaks, sampling_rate=1000, interval_max=None, relative_interval_max=None, robust=False
+    peaks, sampling_rate=1000, interval_max=None, relative_interval_max=None, robust=False,
 ):
     if interval_max is None and relative_interval_max is None:
         return peaks
-
-    continue_loop = True
-    while continue_loop is True:
-        if interval_max is not None:
-            interval = signal_period(peaks, sampling_rate=sampling_rate, desired_length=None)
-            peaks, continue_loop = _interpolate_missing(
-                peaks, interval, interval_max, sampling_rate
-            )
-
+    else:
+        interval = signal_period(peaks, sampling_rate=sampling_rate, desired_length=None)
         if relative_interval_max is not None:
-            interval = signal_period(peaks, sampling_rate=sampling_rate, desired_length=None)
-            interval = standardize(interval, robust=robust)
-            peaks, continue_loop = _interpolate_missing(
-                peaks, interval, relative_interval_max, sampling_rate
-            )
+            outliers = standardize(interval, robust=robust) > relative_interval_max
+        else:
+            outliers = interval > interval_max
+        outliers_loc = np.where(outliers)[0]
 
-    return peaks
+        # interval returned by signal_period at index 0 is the mean of the intervals
+        # so it does not actually correspond to whether the first peak is an outlier
+        outliers_loc = outliers_loc[outliers_loc != 0]
 
+        if np.sum(outliers) == 0:
+            return peaks
+        peaks_to_correct = peaks.copy().astype(float)
 
-def _interpolate_missing(peaks, interval, interval_max, sampling_rate):
-    outliers = interval > interval_max
-    outliers_loc = np.where(outliers)[0]
-    if np.sum(outliers) == 0:
-        return peaks, False
+        interval_without_outliers = interval[np.invert(outliers)]
+        mean_interval = np.nanmean(interval_without_outliers)
 
-    # Delete large interval and replace by two unknown intervals
-    interval[outliers] = np.nan
-    interval = np.insert(interval, outliers_loc, np.nan)
-    #    new_peaks_location = np.where(np.isnan(interval))[0]
+        # go through the outliers starting with the highest indices
+        # so that the indices of the other outliers are not moved when
+        # unknown intervas are inserted
+        for loc in np.flip(outliers_loc):
+            # compute number of NaNs to insert based on the mean interval
+            n_nan = round(interval[loc] / mean_interval)
 
-    # Interpolate values
-    interval = pd.Series(interval).interpolate().values
-    peaks_corrected = _period_to_location(interval, sampling_rate, first_location=peaks[0])
-    peaks = np.insert(
-        peaks, outliers_loc, peaks_corrected[outliers_loc + np.arange(len(outliers_loc))]
-    )
-    return peaks, True
-
-
-def _period_to_location(period, sampling_rate=1000, first_location=0):
-    location = np.cumsum(period * sampling_rate)
-    location = location - (location[0] - first_location)
-    return location.astype(int)
+            # Delete peak corresponding to large interval and replace by N NaNs
+            peaks_to_correct[loc] = np.nan
+            peaks_to_correct = np.insert(peaks_to_correct, loc, [np.nan] * (n_nan - 1))
+        # Interpolate values
+        interpolated_peaks = pd.Series(peaks_to_correct).interpolate(limit_area="inside").values
+        # If there are missing values remaining, remove
+        peaks = interpolated_peaks[np.invert(np.isnan(interpolated_peaks))].astype(peaks.dtype)
+        return peaks
