@@ -22,6 +22,7 @@ def signal_psd(
     order_criteria="KIC",
     order_corrected=True,
     silent=True,
+    t=None,
     **kwargs,
 ):
     """**Compute the Power Spectral Density (PSD)**
@@ -64,6 +65,9 @@ def signal_psd(
         the order, rely on the default (i.e., the corrected KIC).
     silent : bool
         If ``False``, warnings will be printed. Default to ``True``.
+    t : array
+        The timestamps corresponding to each sample in the signal, in seconds
+        (for ``"lombscargle"`` method). Defaults to None.
     **kwargs : optional
         Keyword arguments to be passed to :func:`.scipy.signal.welch`.
 
@@ -138,10 +142,7 @@ def signal_psd(
     # MNE
     if method in ["multitaper", "multitapers", "mne"]:
         frequency, power = _signal_psd_multitaper(
-            signal,
-            sampling_rate=sampling_rate,
-            min_frequency=min_frequency,
-            max_frequency=max_frequency,
+            signal, sampling_rate=sampling_rate, min_frequency=min_frequency, max_frequency=max_frequency,
         )
 
     # FFT (Numpy)
@@ -151,10 +152,7 @@ def signal_psd(
     # Lombscargle (AtroPy)
     elif method.lower() in ["lombscargle", "lomb"]:
         frequency, power = _signal_psd_lomb(
-            signal,
-            sampling_rate=sampling_rate,
-            min_frequency=min_frequency,
-            max_frequency=max_frequency,
+            signal, sampling_rate=sampling_rate, min_frequency=min_frequency, max_frequency=max_frequency, t=t
         )
 
     # Method that are using a window
@@ -183,11 +181,7 @@ def signal_psd(
         # Welch (Scipy)
         if method.lower() in ["welch"]:
             frequency, power = _signal_psd_welch(
-                signal,
-                sampling_rate=sampling_rate,
-                nperseg=nperseg,
-                window_type=window_type,
-                **kwargs,
+                signal, sampling_rate=sampling_rate, nperseg=nperseg, window_type=window_type, **kwargs,
             )
 
         # BURG
@@ -210,15 +204,11 @@ def signal_psd(
     data = pd.DataFrame({"Frequency": frequency, "Power": power})
 
     # Filter
-    data = data.loc[
-        np.logical_and(data["Frequency"] >= min_frequency, data["Frequency"] <= max_frequency)
-    ]
+    data = data.loc[np.logical_and(data["Frequency"] >= min_frequency, data["Frequency"] <= max_frequency)]
     #    data["Power"] = 10 * np.log(data["Power"])
 
     if show is True:
-        ax = data.plot(
-            x="Frequency", y="Power", title="Power Spectral Density (" + str(method) + " method)"
-        )
+        ax = data.plot(x="Frequency", y="Power", title="Power Spectral Density (" + str(method) + " method)")
         ax.set(xlabel="Frequency (Hz)", ylabel="Spectrum")
 
     return data
@@ -295,17 +285,24 @@ def _signal_psd_welch(signal, sampling_rate=1000, nperseg=None, window_type="han
 # =============================================================================
 
 
-def _signal_psd_lomb(signal, sampling_rate=1000, min_frequency=0, max_frequency=np.inf):
+def _signal_psd_lomb(signal, sampling_rate=1000, min_frequency=0, max_frequency=np.inf, t=None):
 
     try:
         import astropy.timeseries
 
-        if max_frequency == np.inf:
-            max_frequency = sampling_rate / 2  # sanitize highest frequency
-        t = np.arange(len(signal)) / sampling_rate
-        frequency, power = astropy.timeseries.LombScargle(t, signal, normalization="psd").autopower(
-            minimum_frequency=min_frequency, maximum_frequency=max_frequency
-        )
+        if t is None:
+            if max_frequency == np.inf:
+                max_frequency = sampling_rate / 2  # sanitize highest frequency
+            t = np.arange(len(signal)) / sampling_rate
+            frequency, power = astropy.timeseries.LombScargle(t, signal, normalization="psd").autopower(
+                minimum_frequency=min_frequency, maximum_frequency=max_frequency
+            )
+        else:
+            # determine maximum frequency with astropy defaults for unevenly spaced data
+            # https://docs.astropy.org/en/stable/api/astropy.timeseries.LombScargle.html#astropy.timeseries.LombScargle.autopower
+            frequency, power = astropy.timeseries.LombScargle(t, signal, normalization="psd").autopower(
+                minimum_frequency=min_frequency
+            )
 
     except ImportError as e:
         raise ImportError(
@@ -323,13 +320,7 @@ def _signal_psd_lomb(signal, sampling_rate=1000, min_frequency=0, max_frequency=
 
 
 def _signal_psd_burg(
-    signal,
-    sampling_rate=1000,
-    order=16,
-    criteria="KIC",
-    corrected=True,
-    side="one-sided",
-    nperseg=None,
+    signal, sampling_rate=1000, order=16, criteria="KIC", corrected=True, side="one-sided", nperseg=None,
 ):
 
     nfft = int(nperseg * 2)
@@ -399,9 +390,7 @@ def _signal_arma_burg(signal, order=16, criteria="KIC", corrected=True):
 
         if criteria is not None:
             # k=k+1 because order goes from 1 to P whereas k starts at 0.
-            residual_new = _criteria(
-                criteria=criteria, N=N, k=k + 1, rho=new_rho, corrected=corrected
-            )
+            residual_new = _criteria(criteria=criteria, N=N, k=k + 1, rho=new_rho, corrected=corrected)
             if k == 0:
                 residual_old = 2.0 * abs(residual_new)
 
@@ -413,9 +402,7 @@ def _signal_arma_burg(signal, order=16, criteria="KIC", corrected=True):
             residual_old = residual_new
         rho = new_rho
         if rho <= 0:
-            raise ValueError(
-                f"Found a negative value (expected positive strictly) {rho}. Decrease the order."
-            )
+            raise ValueError(f"Found a negative value (expected positive strictly) {rho}. Decrease the order.")
 
         ar = np.resize(ar, ar.size + 1)
         ar[k] = kp
@@ -490,9 +477,7 @@ def _criteria(criteria=None, N=None, k=None, rho=None, corrected=True):
 
     elif criteria == "KIC":
         if corrected is True:
-            residual = (
-                np.log(rho) + k / N / (N - k) + (3.0 - (k + 2.0) / N) * (k + 1.0) / (N - k - 2.0)
-            )
+            residual = np.log(rho) + k / N / (N - k) + (3.0 - (k + 2.0) / N) * (k + 1.0) / (N - k - 2.0)
         else:
             residual = np.log(rho) + 3.0 * (k + 1.0) / float(N)
 
@@ -507,9 +492,7 @@ def _criteria(criteria=None, N=None, k=None, rho=None, corrected=True):
     return residual
 
 
-def _signal_psd_from_arma(
-    ar=None, ma=None, rho=1.0, sampling_rate=1000, nfft=None, side="one-sided"
-):
+def _signal_psd_from_arma(ar=None, ma=None, rho=1.0, sampling_rate=1000, nfft=None, side="one-sided"):
 
     if ar is None and ma is None:
         raise ValueError("Either AR or MA model must be provided")
