@@ -3,7 +3,7 @@ import numpy as np
 
 
 def signal_zerocrossings(signal, direction="both"):
-    """Locate the indices where the signal crosses zero.
+    """**Locate the indices where the signal crosses zero**
 
     Note that when the signal crosses zero between two points, the first index is returned.
 
@@ -12,7 +12,8 @@ def signal_zerocrossings(signal, direction="both"):
     signal : Union[list, np.array, pd.Series]
         The signal (i.e., a time series) in the form of a vector of values.
     direction : str
-        Direction in which the signal crosses zero, can be "positive", "negative" or "both" (default).
+        Direction in which the signal crosses zero, can be ``"positive"``, ``"negative"`` or
+        ``"both"`` (default).
 
     Returns
     -------
@@ -21,19 +22,26 @@ def signal_zerocrossings(signal, direction="both"):
 
     Examples
     --------
-    >>> import numpy as np
-    >>> import neurokit2 as nk
-    >>>
-    >>> signal = nk.signal_simulate(duration=5)
-    >>> zeros = nk.signal_zerocrossings(signal)
-    >>> fig = nk.events_plot(zeros, signal)
-    >>> fig #doctest: +SKIP
-    >>>
-    >>> # Only upward or downward zerocrossings
-    >>> up = nk.signal_zerocrossings(signal, direction='up')
-    >>> down = nk.signal_zerocrossings(signal, direction='down')
-    >>> fig = nk.events_plot([up, down], signal)
-    >>> fig #doctest: +SKIP
+    .. ipython:: python
+
+      import neurokit2 as nk
+
+      signal = nk.signal_simulate(duration=5)
+      zeros = nk.signal_zerocrossings(signal)
+      @savefig p_signal_zerocrossings1.png scale=100%
+      nk.events_plot(zeros, signal)
+      @suppress
+      plt.close()
+
+    .. ipython:: python
+
+      # Only upward or downward zerocrossings
+      up = nk.signal_zerocrossings(signal, direction="up")
+      down = nk.signal_zerocrossings(signal, direction="down")
+      @savefig p_signal_zerocrossings2.png scale=100%
+      nk.events_plot([up, down], signal)
+      @suppress
+      plt.close()
 
     """
     df = np.diff(np.sign(signal))
