@@ -13,11 +13,7 @@ def test_bio_process():
     eda = nk.eda_simulate(duration=30, sampling_rate=sampling_rate, scr_number=3)
     emg = nk.emg_simulate(duration=30, sampling_rate=sampling_rate, burst_number=3)
 
-    bio_df, bio_info = nk.bio_process(ecg=ecg,
-                                      rsp=rsp,
-                                      eda=eda,
-                                      emg=emg,
-                                      sampling_rate=sampling_rate)
+    bio_df, bio_info = nk.bio_process(ecg=ecg, rsp=rsp, eda=eda, emg=emg, sampling_rate=sampling_rate)
 
     # SCR components
     scr = [val for key, val in bio_info.items() if "SCR" in key]
@@ -34,34 +30,26 @@ def test_bio_process():
     assert len(bio_info["EMG_Offsets"] == len(bio_info["EMG_Onsets"]))
 
 
-
 def test_bio_analyze():
 
     # Example with event-related analysis
     data = nk.data("bio_eventrelated_100hz")
-    df, info = nk.bio_process(ecg=data["ECG"], rsp=data["RSP"],
-                              eda=data["EDA"], keep=data["Photosensor"],
-                              sampling_rate=100)
-    events = nk.events_find(data["Photosensor"],
-                            threshold_keep='below',
-                            event_conditions=["Negative",
-                                              "Neutral",
-                                              "Neutral",
-                                              "Negative"])
-    epochs = nk.epochs_create(df, events,
-                              sampling_rate=100,
-                              epochs_start=-0.1, epochs_end=1.9)
+    df, info = nk.bio_process(
+        ecg=data["ECG"], rsp=data["RSP"], eda=data["EDA"], keep=data["Photosensor"], sampling_rate=100
+    )
+    events = nk.events_find(
+        data["Photosensor"], threshold_keep="below", event_conditions=["Negative", "Neutral", "Neutral", "Negative"]
+    )
+    epochs = nk.epochs_create(df, events, sampling_rate=100, epochs_start=-0.1, epochs_end=1.9)
     event_related = nk.bio_analyze(epochs)
 
     assert len(event_related) == len(epochs)
-    labels = [int(i) for i in event_related['Label']]
-    assert labels == list(np.arange(1, len(epochs)+1))
-
+    labels = [int(i) for i in event_related["Label"]]
+    assert labels == list(np.arange(1, len(epochs) + 1))
 
     # Example with interval-related analysis
     data = nk.data("bio_resting_8min_100hz")
-    df, info = nk.bio_process(ecg=data["ECG"], rsp=data["RSP"],
-                              eda=data["EDA"], sampling_rate=100)
+    df, info = nk.bio_process(ecg=data["ECG"], rsp=data["RSP"], eda=data["EDA"], sampling_rate=100)
     interval_related = nk.bio_analyze(df)
 
     assert len(interval_related) == 1
